pub enum DatabaseClient {
Postgres(PgPool),
}Expand description
The database client, wrapping an sqlx connection pool.
Supports PostgreSQL and SQLite via feature flags.
Variants
Implementations
Sourceimpl DatabaseClient
impl DatabaseClient
Sourcepub async fn connect_postgres(url: &str) -> Result<Self, FerriormError>
pub async fn connect_postgres(url: &str) -> Result<Self, FerriormError>
Connect to a PostgreSQL database.
Sourcepub async fn connect_postgres_with_config(
url: &str,
config: &PoolConfig,
) -> Result<Self, FerriormError>
pub async fn connect_postgres_with_config( url: &str, config: &PoolConfig, ) -> Result<Self, FerriormError>
Connect to a PostgreSQL database with custom pool configuration.
Sourcepub async fn connect(url: &str) -> Result<Self, FerriormError>
pub async fn connect(url: &str) -> Result<Self, FerriormError>
Connect by auto-detecting the database type from the URL.
Sourcepub async fn connect_with_config(
url: &str,
config: &PoolConfig,
) -> Result<Self, FerriormError>
pub async fn connect_with_config( url: &str, config: &PoolConfig, ) -> Result<Self, FerriormError>
Connect by auto-detecting the database type from the URL, using custom pool configuration.
Sourcepub fn pg_pool(&self) -> Result<&PgPool, FerriormError>
pub fn pg_pool(&self) -> Result<&PgPool, FerriormError>
Get a reference to the underlying PostgreSQL pool for raw queries.
Returns an error if this client is not connected to PostgreSQL.
Sourcepub async fn disconnect(self)
pub async fn disconnect(self)
Close the connection pool.
Sourcepub async fn raw_fetch_all_pg<T>(
&self,
sql: &str,
) -> Result<Vec<T>, FerriormError>
pub async fn raw_fetch_all_pg<T>( &self, sql: &str, ) -> Result<Vec<T>, FerriormError>
Execute raw SQL and return all rows mapped to T (PostgreSQL).
Sourcepub async fn raw_fetch_one_pg<T>(&self, sql: &str) -> Result<T, FerriormError>
pub async fn raw_fetch_one_pg<T>(&self, sql: &str) -> Result<T, FerriormError>
Execute raw SQL and return exactly one row mapped to T (PostgreSQL).
Sourcepub async fn raw_fetch_optional_pg<T>(
&self,
sql: &str,
) -> Result<Option<T>, FerriormError>
pub async fn raw_fetch_optional_pg<T>( &self, sql: &str, ) -> Result<Option<T>, FerriormError>
Execute raw SQL and return an optional row mapped to T (PostgreSQL).
Sourcepub async fn raw_execute_pg(&self, sql: &str) -> Result<u64, FerriormError>
pub async fn raw_execute_pg(&self, sql: &str) -> Result<u64, FerriormError>
Execute raw SQL without returning rows (PostgreSQL). Returns the number of rows affected.
Sourcepub async fn fetch_all_pg<'q, T>(
&self,
qb: QueryBuilder<'q, Postgres>,
) -> Result<Vec<T>, FerriormError>
pub async fn fetch_all_pg<'q, T>( &self, qb: QueryBuilder<'q, Postgres>, ) -> Result<Vec<T>, FerriormError>
Execute a query builder against the appropriate pool, returning all rows.
pub async fn fetch_optional_pg<'q, T>( &self, qb: QueryBuilder<'q, Postgres>, ) -> Result<Option<T>, FerriormError>
pub async fn fetch_one_pg<'q, T>( &self, qb: QueryBuilder<'q, Postgres>, ) -> Result<T, FerriormError>
pub async fn execute_pg<'q>( &self, qb: QueryBuilder<'q, Postgres>, ) -> Result<u64, FerriormError>